
# Slot: number_of_end_activities

The number of end activities in a model

URI: [gocam:queryIndex__number_of_end_activities](https://w3id.org/gocam/queryIndex__number_of_end_activities)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
